@@ -17,7 +17,7 @@
  */
 
 /*
- * @file manage.h
+ * @file
  * @brief Headers for Greenbone Vulnerability Manager: the Manage library.
  */
 
@@ -25,6 +25,11 @@
 #define _GVMD_MANAGE_H
 
 #include "iterator.h"
+#include "manage_agent_installers.h"
+#include "manage_filter_utils.h"
+#include "manage_resources.h"
+#include "manage_settings.h"
+
 #include "manage_alerts.h"
 #include "manage_configs.h"
 #include "manage_events.h"
@@ -49,6 +54,12 @@
 #include <gvm/openvasd/openvasd.h>
 #endif
 
+#if ENABLE_AGENTS
+#include <gvm/agent_controller/agent_controller.h>
+#include "manage_agent_groups.h"
+#include "manage_agents.h"
+#endif
+
 /**
  * @brief OID of ping_host.nasl
  */
@@ -139,26 +150,14 @@ manage_cleanup_process_error (int);
 void
 manage_reset_currents ();
 
-
 /* Commands. */
 
 #define MAX_LOCK_RETRIES 16
 
-/**
- * @brief A command.
- */
-typedef struct
-{
-  gchar *name;     ///< Command name.
-  gchar *summary;  ///< Summary of command.
-} command_t;
+#define MAX_DATABASE_CONNECTIONS_DEFAULT 50
 
-/**
- * @brief The GMP command list.
- */
-extern command_t gmp_commands[];
+#define MAX_REPORT_PROCESSING_DEFAULT 30
 
-
 /* Certificate and key management. */
 
 gchar*
@@ -261,7 +260,17 @@ void
 manage_transaction_stop (gboolean);
 
 
-/* Task structures. */
+/* Task macros and structures. */
+
+/**
+ * @brief Default for Scanner max_checks preference.
+ */
+#define MAX_CHECKS_DEFAULT "4"
+
+/**
+ * @brief Default for Scanner max_hosts preference.
+ */
+#define MAX_HOSTS_DEFAULT "20"
 
 /**
  * @brief Task statuses, also used as scan/report statuses.
@@ -329,7 +338,10 @@ typedef enum scanner_type
   /* 4 was removed (SCANNER_TYPE_GMP). */
   SCANNER_TYPE_OSP_SENSOR = 5,
   SCANNER_TYPE_OPENVASD = 6,
-  SCANNER_TYPE_MAX = 7,
+  SCANNER_TYPE_AGENT_CONTROLLER = 7,
+  SCANNER_TYPE_OPENVASD_SENSOR = 8,
+  SCANNER_TYPE_AGENT_CONTROLLER_SENSOR = 9,
+  SCANNER_TYPE_MAX = 10,
 } scanner_type_t;
 
 int
@@ -338,44 +350,6 @@ scanner_type_valid (scanner_type_t);
 int
 scanner_type_supports_unix_sockets (scanner_type_t);
 
-typedef resource_t credential_t;
-typedef resource_t filter_t;
-typedef resource_t group_t;
-typedef resource_t host_t;
-typedef resource_t tag_t;
-typedef resource_t target_t;
-typedef resource_t ticket_t;
-typedef resource_t tls_certificate_t;
-typedef resource_t result_t;
-typedef resource_t report_t;
-typedef resource_t report_host_t;
-typedef resource_t report_config_t;
-typedef resource_t report_config_param_t;
-typedef resource_t report_format_t;
-typedef resource_t report_format_param_t;
-typedef resource_t role_t;
-typedef resource_t note_t;
-typedef resource_t nvt_t;
-typedef resource_t override_t;
-typedef resource_t permission_t;
-typedef resource_t port_list_t;
-typedef resource_t port_range_t;
-typedef resource_t schedule_t;
-typedef resource_t scanner_t;
-typedef resource_t setting_t;
-typedef resource_t user_t;
-
-
-/* GMP GET support.
- *
- * The standalone parts of the GET support are in manage_get.h. */
-
-resource_t
-get_iterator_resource (iterator_t*);
-
-user_t
-get_iterator_owner (iterator_t*);
-
 
 /* Resources. */
 
@@ -400,15 +374,6 @@ find_resource (const char*, const char*, resource_t*);
 gboolean
 find_resource_no_acl (const char*, const char*, resource_t*);
 
-const char *
-type_name_plural (const char*);
-
-const char *
-type_name (const char*);
-
-int
-type_is_scap (const char*);
-
 int
 delete_resource (const char *, const char *, int);
 
@@ -641,6 +606,21 @@ task_target_in_trash (task_t);
 void
 set_task_target (task_t, target_t);
 
+#if ENABLE_AGENTS
+void
+set_task_agent_group_and_location (task_t task, agent_group_t agent_group);
+
+int
+agent_group_tasks_exist_by_scanner (scanner_t scanner);
+
+int
+agent_group_hidden_tasks_exist_by_scanner (scanner_t scanner);
+#endif /* ENABLE_AGENTS */
+
+int
+set_task_schedule_and_periods (task_t task, const gchar *schedule_id,
+                               const gchar *schedule_periods);
+
 void
 set_task_hosts_ordering (task_t, const char *);
 
@@ -813,7 +793,7 @@ int
 modify_task (const gchar *, const gchar *, const gchar *, const gchar *,
              const gchar *, const gchar *, const gchar *, array_t *,
              const gchar *, array_t *, const gchar *, const gchar *,
-             array_t *, const gchar *, gchar **, gchar **);
+             array_t *, const gchar *, const gchar *, gchar **, gchar **);
 
 void
 init_config_file_iterator (iterator_t*, const char*, const char*);
@@ -839,6 +819,9 @@ config_task_iterator_readable (iterator_t*);
 
 /* General severity related facilities. */
 
+const char *
+threat_message_type (const char *);
+
 int
 severity_in_level (double, const char *);
 
@@ -889,6 +872,9 @@ severity_data_level_counts (const severity_data_t*,
 const char*
 run_status_name (task_status_t);
 
+void
+set_task_interrupted (task_t, const gchar *);
+
 int
 start_task (const char *, char**);
 
@@ -997,21 +983,11 @@ result_detection_reference (result_t, report_t, const char *, const char *,
 
 /* Reports. */
 
-/**
- * @brief Default apply_overrides setting
- */
-#define APPLY_OVERRIDES_DEFAULT 0
-
 /**
  * @brief Default quality of detection percentage.
  */
 #define QOD_DEFAULT 75
 
-/**
- * @brief Default min quality of detection percentage for filters.
- */
-#define MIN_QOD_DEFAULT 70
-
 /**
  * @brief Default size to limit note and override text to in reports.
  */
@@ -1044,6 +1020,12 @@ find_report_with_permission (const char *, report_t *, const char *);
 report_t
 make_report (task_t, const char *, task_status_t);
 
+void
+manage_queued_task_actions ();
+
+void
+manage_process_report_imports ();
+
 int
 qod_from_type (const char *);
 
@@ -1109,9 +1091,6 @@ insert_report_host_detail (report_t, const char *, const char *, const char *,
                            const char *, const char *, const char *,
                            const char *);
 
-int
-manage_report_host_detail (report_t, const char *, const char *, GHashTable *);
-
 void
 hosts_set_identifiers (report_t);
 
@@ -1238,6 +1217,9 @@ init_report_iterator_task (iterator_t*, task_t);
 void
 init_report_errors_iterator (iterator_t*, report_t);
 
+void
+init_report_awaiting_processing_iterator (iterator_t*, int);
+
 const char*
 report_iterator_uuid (iterator_t*);
 
@@ -1644,10 +1626,10 @@ manage_report_filter_controls (const gchar *, int *, int *, gchar **, int *,
                                gchar **, int *, int *, int *, int *, gchar **);
 
 gchar *
-manage_clean_filter (const gchar *);
+manage_clean_filter (const gchar *, int);
 
 gchar *
-manage_clean_filter_remove (const gchar *, const gchar *);
+manage_clean_filter_remove (const gchar *, const gchar *, int);
 
 int
 manage_count_hosts (const char *, const char *);
@@ -2132,7 +2114,8 @@ int
 create_credential (const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
-                   const char*, const char*, const char*, credential_t*);
+                   array_t*,    const char*, const char*, const char*,
+                   credential_t*);
 
 int
 copy_credential (const char*, const char*, const char*,
@@ -2142,7 +2125,7 @@ int
 modify_credential (const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
-                   const char*, const char*, const char*);
+                   const char*, array_t*, const char*, const char*);
 
 int
 delete_credential (const char *, int);
@@ -2246,6 +2229,20 @@ credential_target_iterator_name (iterator_t*);
 int
 credential_target_iterator_readable (iterator_t*);
 
+#if ENABLE_CONTAINER_SCANNING
+void
+init_credential_oci_image_target_iterator (iterator_t*, credential_t, int);
+
+const char*
+credential_oci_target_iterator_uuid (iterator_t*);
+
+const char*
+credential_oci_target_iterator_name (iterator_t*);
+
+int
+credential_oci_target_iterator_readable (iterator_t*);
+#endif /* ENABLE_CONTAINER_SCANNING */
+
 void
 init_credential_scanner_iterator (iterator_t*, credential_t, int);
 
@@ -2283,40 +2280,10 @@ credential_encrypted_value (credential_t, const char*);
 
 /* Assets. */
 
-char *
-result_host_asset_id (const char *, result_t);
-
-char*
-host_uuid (resource_t);
-
 host_t
 host_notice (const char *, const char *, const char *, const char *,
              const char *, int, int);
 
-void
-init_host_identifier_iterator (iterator_t*, host_t, int, const char*);
-
-const char*
-host_identifier_iterator_value (iterator_t *);
-
-const char*
-host_identifier_iterator_source_type (iterator_t *);
-
-const char*
-host_identifier_iterator_source_id (iterator_t *);
-
-const char*
-host_identifier_iterator_source_data (iterator_t *);
-
-int
-host_identifier_iterator_source_orphan (iterator_t *);
-
-const char*
-host_identifier_iterator_os_id (iterator_t *);
-
-const char*
-host_identifier_iterator_os_title (iterator_t *);
-
 int
 init_asset_host_iterator (iterator_t *, const get_data_t *);
 
@@ -2392,12 +2359,6 @@ modify_asset (const char *, const char *);
 int
 delete_asset (const char *, const char *, int);
 
-int
-create_asset_report (const char *, const char *);
-
-int
-create_asset_host (const char *, const char *, resource_t* );
-
 int
 add_assets_from_host_in_report (report_t report, const char *host);
 
@@ -2752,6 +2713,9 @@ scanner_iterator_ca_pub (iterator_t *);
 const char*
 scanner_iterator_key_pub (iterator_t *);
 
+const char*
+scanner_iterator_key_priv (iterator_t*);
+
 const char*
 scanner_iterator_credential_type (iterator_t *);
 
@@ -2795,17 +2759,6 @@ osp_get_version_from_iterator (iterator_t *, char **, char **, char **, char **,
 int
 osp_get_details_from_iterator (iterator_t *, char **, GSList **);
 
-osp_connection_t *
-osp_connect_with_data (const char *,
-                       int,
-                       const char *,
-                       const char *,
-                       const char *,
-                       gboolean);
-
-osp_connection_t *
-osp_scanner_connect (scanner_t);
-
 int
 get_scanner_connection_retry ();
 
@@ -2849,6 +2802,11 @@ slave_relay_connection (gvm_connection_t *, gvm_connection_t *);
  */
 #define SCHEDULE_PERIOD 10
 
+/**
+ * @brief Seconds between calls to manage_queued_task_actions.
+ */
+#define QUEUE_PERIOD 5
+
 /**
  * @brief Minimum schedule timeout seconds.
  * This value must be greater than SCHEDULE_PERIOD.
@@ -3129,66 +3087,6 @@ role_count (const get_data_t*);
 int
 modify_role (const char *, const char *, const char *, const char *);
 
-
-/* Filter Utilities. */
-
-/**
- * @brief Keyword type.
- */
-typedef enum
-{
-  KEYWORD_TYPE_UNKNOWN,
-  KEYWORD_TYPE_INTEGER,
-  KEYWORD_TYPE_DOUBLE,
-  KEYWORD_TYPE_STRING
-} keyword_type_t;
-
-/**
- * @brief Comparison returns.
- */
-typedef enum
-{
-  KEYWORD_RELATION_APPROX,
-  KEYWORD_RELATION_COLUMN_ABOVE,
-  KEYWORD_RELATION_COLUMN_APPROX,
-  KEYWORD_RELATION_COLUMN_EQUAL,
-  KEYWORD_RELATION_COLUMN_BELOW,
-  KEYWORD_RELATION_COLUMN_REGEXP
-} keyword_relation_t;
-
-/**
- * @brief Keyword.
- */
-struct keyword
-{
-  gchar *column;                 ///< The column prefix, or NULL.
-  int approx;                    ///< Whether the keyword is like "~example".
-  int equal;                     ///< Whether the keyword is like "=example".
-  int integer_value;             ///< Integer value of the keyword.
-  double double_value;           ///< Floating point value of the keyword.
-  int quoted;                    ///< Whether the keyword was quoted.
-  gchar *string;                 ///< The keyword string, outer quotes removed.
-  keyword_type_t type;           ///< Type of keyword.
-  keyword_relation_t relation;   ///< The relation.
-};
-
-/**
- * @brief Keyword type.
- */
-typedef struct keyword keyword_t;
-
-int
-keyword_special (keyword_t *);
-
-const char *
-keyword_relation_symbol (keyword_relation_t);
-
-void
-filter_free (array_t*);
-
-array_t *
-split_filter (const gchar*);
-
 
 /* Filters. */
 
@@ -3220,18 +3118,6 @@ filter_name (filter_t);
 char*
 trash_filter_name (filter_t);
 
-gchar*
-filter_term (const char *);
-
-gchar*
-filter_term_value (const char *, const char *);
-
-int
-filter_term_apply_overrides (const char *);
-
-int
-filter_term_min_qod (const char *);
-
 int
 create_filter (const char*, const char*, const char*, const char*, filter_t*);
 
@@ -3309,6 +3195,11 @@ info_name_count (const gchar *, const gchar *);
 int
 manage_scap_loaded ();
 
+#if FEED_VT_METADATA == 1
+int
+manage_nvts_loaded ();
+#endif
+
 const char *
 manage_scap_update_time ();
 
@@ -3476,7 +3367,7 @@ secinfo_count_after (const get_data_t *, const char *, time_t, gboolean);
 /* Settings. */
 
 int
-manage_max_rows (int);
+manage_max_rows (int, int);
 
 int
 setting_count (const char *);
@@ -3506,9 +3397,6 @@ setting_iterator_comment (iterator_t*);
 const char*
 setting_iterator_value (iterator_t*);
 
-int
-setting_value_int (const char *, int *);
-
 int
 modify_setting (const gchar *, const gchar *, const gchar *, gchar **);
 
@@ -3536,15 +3424,9 @@ manage_delete_user (GSList *, const db_conn_info_t *, const gchar *,
 int
 manage_get_users (GSList *, const db_conn_info_t *, const gchar *, int);
 
-report_host_t
-manage_report_host_add (report_t, const char *, time_t, time_t);
-
 int
 report_host_noticeable (report_t, const gchar *);
 
-void
-report_host_set_end_time (report_host_t, time_t);
-
 gchar*
 host_routes_xml (host_t);
 
@@ -3677,7 +3559,7 @@ vuln_count (const get_data_t*);
 void
 manage_get_ldap_info (int *, gchar **, gchar **, int *, gchar **, int *);
 
-void
+int
 manage_set_ldap_info (int, gchar *, gchar *, int, gchar *, int);
 
 char *
@@ -3874,6 +3756,18 @@ get_max_concurrent_scan_updates ();
 void
 set_max_concurrent_scan_updates (int);
 
+int
+get_max_database_connections ();
+
+void
+set_max_database_connections (int);
+
+int
+get_max_concurrent_report_processing ();
+
+void
+set_max_concurrent_report_processing (int);
+
 int
 get_mem_wait_retries ();
 
